@@ -6,7 +6,7 @@ def get_channel(connection, queue_name, durable=True, confirm_delivery=True, is_
     """ Init method to return a prepared channel for consuming
     """
     channel = connection.channel()
-    args = {'x-max-priority': 255}
+    args = {'x-max-priority': 10}
     if is_lazy:
         args['x-queue-mode'] = 'lazy'
     channel.queue_declare(queue=queue_name, durable=durable, arguments=args)
@@ -15,11 +15,8 @@ def get_channel(connection, queue_name, durable=True, confirm_delivery=True, is_
 
     if is_delay is True:
         exchange_name = "{}-delay".format(queue_name)
-        channel.exchange_declare(exchange_name,
-                                 exchange_type="x-delayed-message",
-                                 arguments={"x-delayed-type": "direct"})
-        channel.queue_bind(
-            queue=queue_name, exchange=exchange_name, routing_key=queue_name)
+        channel.exchange_declare(exchange_name,exchange_type="x-delayed-message",arguments={"x-delayed-type": "direct"})
+        channel.queue_bind(queue=queue_name, exchange=exchange_name, routing_key=queue_name)
     return channel
 
 
