@@ -2,7 +2,7 @@
 import scrapy
 import pickle
 import json
-from scrapy.utils.reqser import request_from_dict
+from scrapy.utils.request import request_from_dict
 
 
 class RabbitSpider(scrapy.Spider):
